Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FormatJSONSyntaxError ¶
FormatJSONSyntaxError generates a pretty printed json syntax error since golang doesn't provide an easy way to report the location of the error
func GetVersion ¶
GetVersion - extracts the version information.
Types ¶
type Config ¶
type Config interface {
String() string
Version() string
Save(string) error
Load(string) error
Data() interface{}
Diff(Config) ([]structs.Field, error)
DeepDiff(Config) ([]structs.Field, error)
}
Config - generic config interface functions
Click to show internal directories.
Click to hide internal directories.